@@ -3,12 +3,13 @@
 viledatools
 """
 
-__version__ = "1.0.31"
+__version__ = "1.0.38"
 
 from typing import Tuple
 
 from .apiutils import (FARequests as FARequests, fagetrefs as fagetrefs, getcookieval as getcookieval,
-                       gettag as gettag, make_search_string as make_search_string)
+                       gettag as gettag, make_search_string as make_search_string,
+                       make_search_list as make_search_list)
 from .diagonaltablewalk import DiagonalTableWalk as DiagonalTableWalk
 from .fatask import FATask as FATask
 from .importcellparser import ImportCellParser as ImportCellParser
@@ -20,6 +21,7 @@ from .viledautils import ViledaUtils as ViledaUtils
 __all__: Tuple[str, ...] = (
         "fagetrefs",
         "make_search_string",
+        "make_search_list",
         "FARequests",
         "getcookieval",
         "gettag",
