@@ -6,19 +6,20 @@ Class parsing value from MS Excel cell given, depending on Excel field key provi
 """
 
 import inspect
+import re
 import types
 from datetime import datetime, timedelta
-from typing import Any, List, Optional, Tuple, Union
+from typing import Any, List, Optional, Tuple, Union, AnyStr, Pattern
 
 import openpyxl
 from openpyxl.cell.cell import Cell
 
 from .fatask import FATask
 from .viledaexceptions import ImportCellParserException
-from .apiutils import strnorm
+from .apiutils import make_search_string
 
 
-# noinspection PyPep8Naming
+# noinspection PyPep8Naming,PyMethodMayBeStatic
 class ImportCellParser:
     """
     Class parsing value from MS Excel cell given, depending on Excel field key provided
@@ -36,6 +37,8 @@ class ImportCellParser:
             if fieldkey not in self._parsers_list:
                 raise ImportCellParserException(f"Unknown field key: {fieldkey}")
             self._method = getattr(self, fieldkey)
+        # Compile regular expression pattern for make_search_string()
+        self._re_pattern: Pattern[AnyStr] = re.compile("[ .,:;-]+")
 
     def parse(self, cellobject: openpyxl.cell.cell.Cell) -> Any:
         """
@@ -52,7 +55,7 @@ class ImportCellParser:
         """
         return self._parsers_list
 
-    def _parsenames(self, cellobject: openpyxl.cell.cell.Cell, sep: str) -> Union[List[str], None]:
+    def _parsenames(self, cellobject: openpyxl.cell.cell.Cell, sep: str) -> Union[List[List[str]], None]:
         """
         Parse list of task owners from cell value, use given separator string
 
@@ -68,10 +71,10 @@ class ImportCellParser:
         for _item in _value_raw_list:
             _trimmed_item = _item.strip()
             if _trimmed_item:
-                _value_users_list.append(chr(0x0020).join(strnorm(_trimmed_item)))
+                _value_users_list.append(make_search_string(_trimmed_item, self._re_pattern))
         return _value_users_list if _value_users_list else None
 
-    def _parse_spaces_list(self, cellobject: openpyxl.cell.cell.Cell, sep: str) -> Union[List[str], None]:
+    def _parse_spaces_list(self, cellobject: openpyxl.cell.cell.Cell, sep: str) -> Union[List[List[str]], None]:
         """
         Parse list of space names from cell value, use given separator string
 
@@ -87,7 +90,7 @@ class ImportCellParser:
         for _item in _value_raw_list:
             _trimmed_item = _item.strip()
             if _trimmed_item:
-                _value_spaces_list.append(chr(0x0020).join(strnorm(_trimmed_item)))
+                _value_spaces_list.append(make_search_string(_trimmed_item, self._re_pattern))
         return _value_spaces_list if _value_spaces_list else None
 
     def _parseyesno(self, cellobject: openpyxl.cell.cell.Cell) -> Union[bool, None]:
@@ -147,7 +150,7 @@ class ImportCellParser:
             raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
         if cellobject.value is None:
             return None
-        return chr(0x0020).join(strnorm(cellobject.value))
+        return make_search_string(cellobject.value, self._re_pattern)
 
     def IQF002FLOOR(self, cellobject: openpyxl.cell.cell.Cell) -> Union[str, None]:
         """
@@ -160,7 +163,7 @@ class ImportCellParser:
             raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
         if cellobject.value is None:
             return None
-        return chr(0x0020).join(strnorm(cellobject.value))
+        return make_search_string(cellobject.value, self._re_pattern)
 
     def IQF003SPACE(self, cellobject: openpyxl.cell.cell.Cell) -> Union[str, None]:
         """
@@ -173,7 +176,7 @@ class ImportCellParser:
             raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
         if cellobject.value is None:
             return None
-        return chr(0x0020).join(strnorm(cellobject.value))
+        return make_search_string(cellobject.value, self._re_pattern)
 
     def IQF004TASKOWNERS(self, cellobject: openpyxl.cell.cell.Cell) -> Union[List[str], None]:
         """
@@ -655,3 +658,69 @@ class ImportCellParser:
             raise ImportCellParserException((f"IQF028TASKDURATION: Wrong cell contents {_value.strip()}, "
                                              f"must be strictly in format H:M:S"))
         return _output
+
+    def IQF029NFCSPACESCONTROL(self, cellobject: openpyxl.cell.cell.Cell) -> Union[List[str], None]:
+        """
+        Space list used to detect control of cleaning of the room by NFC linked to the space.
+        Parse list of spaces from cell value, return list of normalized names of spaces with strnorm(). In the
+        MS Excel sheet cell value space names must be separated with ; (semicolon) symbol, empty values between
+        separators will be just ignored.
+        :param cellobject: openpyxl cell object to parse
+        :return: normalized spaces' names in a list() parsed from the cell
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        if not isinstance(cellobject.value, str):
+            raise ImportCellParserException((f"IQF029NFCSPACESCONTROL: Cell contents type is {type(cellobject.value)}, "
+                                             f"string type required"))
+        return self._parse_spaces_list(cellobject, ";")
+
+    def IQF030NFCSITE(self, cellobject: openpyxl.cell.cell.Cell) -> Union[str, None]:
+        """
+        Parse site name for NFC control, normalize with _parse_spaces_list()
+        :param cellobject: openpyxl cell object to parse
+        :return: normalized site name string parsed from the cell
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        return make_search_string(cellobject.value, self._re_pattern)
+
+    def IQF031NFCFLOOR(self, cellobject: openpyxl.cell.cell.Cell) -> Union[str, None]:
+        """
+        Parse floor name for NFC control, normalize with _parse_spaces_list()
+        :param cellobject: openpyxl cell object to parse
+        :return: normalized floor name parsed from the cell
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        return make_search_string(cellobject.value, self._re_pattern)
+
+    def IQF032TASKTIMEDAYSHIFT(self, cellobject: openpyxl.cell.cell.Cell) -> Union[int, None]:
+        """
+        Parse value as integer, defines how many days are in between task start time and task end time, 0 means
+        task start and ends the same day, positive values mean task ends in specified number of days after start date,
+        negative values are not allowed
+
+        :param cellobject: openpyxl cell object to parse
+        :return: relative integer day shift of end task time to start task time
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        _value = cellobject.value
+        try:
+            _value_int = int(_value)
+        except Exception:
+            raise ImportCellParserException(f"IQF032TASKTIMEDAYSHIFT: Wrong value in the cell: "
+                                            f"{_value}, must be integer")
+        if _value_int < 0:
+            raise ImportCellParserException((f"IQF032TASKTIMEDAYSHIFT: Value in the cell: {_value} out of range, "
+                                             f"day shift must be equal or greater than 0"))
+        return _value_int
