@@ -22,8 +22,15 @@ class ViledaUtils:
     Static class containig various methods to use for import / export, API communication, convertations
     """
 
+    def __init__(self):
+        pass
+
     @staticmethod
-    def loadexcels(xlsdir: str, tolog: logging.Logger, pfile: Optional[str] = None) -> List[Dict[str, Any]]:
+    def loadexcels(xlsdir: str,
+                   tolog: logging.Logger,
+                   pfile: Optional[str] = None,
+                   loglist: Optional[List[Dict[str, Any]]] = None,
+                   logdebug: bool = False) -> List[Dict[str, Any]]:
         """
         Loads all excels from given folder, parses all records in all sheets, and returns a list of dicts representing
         records found in sheets. From sheet to sheet records can contain different sets of fields, which is allowed.
@@ -34,6 +41,10 @@ class ViledaUtils:
         :param tolog: logger object to use
         :param pfile: file to record import progress, one single file created, by default is "progress" in the
                       same xlsdir folder, or full path/filename can be specified explicitly by this parameter
+        :param loglist: if reference to the list object provided, then logging to this list by using append() method,
+                        each record is a dict like {"level": log level, "msg": log message}
+                        in case if loglist is not None logger provider by tolog parameter is not used
+        :param logdebug: log debug messages
         :return: list of task records loaded from excel sheets
         """
         # List of workbooks
@@ -52,7 +63,11 @@ class ViledaUtils:
                         wbs[_tmp_name_walk_f] = load_workbook(filename=f"{xlsdir.strip('/')}/{_tmp_name_walk_f}")
                         _log_wbs_list.append(_tmp_name_walk_f)
                 except Exception:
-                    tolog.warning(f"Can't load {xlsdir.strip('/')}/{_tmp_name_walk_f}:\n{format_exc()}")
+                    if isinstance(loglist, list):
+                        loglist.append({"level": "WARNING",
+                                       "msg": f"Can't load {xlsdir.strip('/')}/{_tmp_name_walk_f}:\n{format_exc()}"})
+                    else:
+                        tolog.warning(f"Can't load {xlsdir.strip('/')}/{_tmp_name_walk_f}:\n{format_exc()}")
         # Log loaded workbooks
         if _log_wbs_list:
             _log_str = (f"\nLoaded {len(_log_wbs_list)} "
@@ -61,7 +76,11 @@ class ViledaUtils:
                         f"{', '.join([(chr(39) + _i + chr(39)) for _i in _log_wbs_list])}")
         else:
             _log_str = "\nNo MS Excel workbooks loaded"
-        tolog.info(_log_str)
+        if isinstance(loglist, list):
+            loglist.append({"level": "INFO",
+                            "msg": _log_str})
+        else:
+            tolog.info(_log_str)
         # Full list for importing
         reclist = list()
         # Log record string
@@ -94,12 +113,21 @@ class ViledaUtils:
         _log_str_loading += (f"   TOTAL {len(reclist)} "
                              f"record{'s' if len(reclist) != 1 else ''}\n")
         # Log records loading
-        tolog.info(_log_str_loading)
+        if isinstance(loglist, list):
+            loglist.append({"level": "INFO",
+                            "msg": _log_str_loading})
+        else:
+            tolog.info(_log_str_loading)
         # Log full imported list
         _log_str_reclist = str()
         for _r in reclist:
             _log_str_reclist += str(_r) + "\n"
-        tolog.debug(_log_str_reclist)
+        if logdebug:
+            if isinstance(loglist, list):
+                loglist.append({"level": "DEBUG",
+                                "msg": _log_str_reclist})
+            else:
+                tolog.debug(_log_str_reclist)
         # And finally return the list
         return reclist
 
